==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSZoneConditionBuilder extends io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluentImpl<io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition,io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionBuilder>{
  public DNSZoneConditionBuilder() {
    this(false);
  }
  public DNSZoneConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSZoneCondition(), validationEnabled);
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSZoneCondition(), validationEnabled);
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition instance) {
    this(fluent, instance, false);
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition instance) {
    this(instance,false);
  }
  public DNSZoneConditionBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.DNSZoneConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.DNSZoneCondition build() {
    DNSZoneCondition buildable = new DNSZoneCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneConditionBuilder that = (DNSZoneConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSZoneConditionBuilder extends DNSZoneConditionFluentImpl<DNSZoneConditionBuilder> implements VisitableBuilder<DNSZoneCondition,DNSZoneConditionBuilder>{
  public DNSZoneConditionBuilder() {
    this(false);
  }
  public DNSZoneConditionBuilder(Boolean validationEnabled) {
    this(new DNSZoneCondition(), validationEnabled);
  }
  public DNSZoneConditionBuilder(DNSZoneConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneConditionBuilder(DNSZoneConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSZoneCondition(), validationEnabled);
  }
  public DNSZoneConditionBuilder(DNSZoneConditionFluent<?> fluent,DNSZoneCondition instance) {
    this(fluent, instance, false);
  }
  public DNSZoneConditionBuilder(DNSZoneConditionFluent<?> fluent,DNSZoneCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneConditionBuilder(DNSZoneCondition instance) {
    this(instance,false);
  }
  public DNSZoneConditionBuilder(DNSZoneCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSZoneConditionFluent<?> fluent;
  Boolean validationEnabled;
  public DNSZoneCondition build() {
    DNSZoneCondition buildable = new DNSZoneCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
